@@ -38,14 +38,14 @@ namespace
 bool convInterval(const QString& timeParam, KARecurrence::Type&, int& timeInterval, bool allowMonthYear = false);
 }
 
-CommandOptions* CommandOptions::mFirstInstance = Q_NULLPTR;
+CommandOptions* CommandOptions::mFirstInstance = nullptr;
 
 CommandOptions::CommandOptions()
-  : mParser(Q_NULLPTR),
-    mOptions(Num_Options, Q_NULLPTR),
+  : mParser(nullptr),
+    mOptions(Num_Options, nullptr),
     mCommand(NONE),
     mEditActionSet(false),
-    mRecurrence(Q_NULLPTR),
+    mRecurrence(nullptr),
     mRepeatCount(0),
     mRepeatInterval(0),
     mLateCancel(0),
