@@ -48,6 +48,8 @@
 #include "timeedit.h"
 #include "timespinbox.h"
 
+#include <KAlarmCal/Utils>
+
 #include <Libkdepim/MaillistDrag>
 
 #include <kglobal.h>
@@ -1313,7 +1315,7 @@ void EditAlarmDlg::slotEditDeferral()
                 mTimeWidget->getDateTime();    // output the appropriate error message
                 return;
             }
-            start = repetition.duration(repeatNum).end(start.kDateTime());
+            start = q2k(repetition.duration(repeatNum).end(k2q(start.kDateTime())));
         }
     }
 
