@@ -44,6 +44,7 @@
 
 #include <kalarmcal/alarmtext.h>
 #include <kalarmcal/kaevent.h>
+#include <kalarmcal/utils.h>
 
 #include <Libkdepim/MaillistDrag>
 #include <kmime/kmime_content.h>
@@ -80,6 +81,7 @@ using namespace KCalUtils;
 #include <qinputdialog.h>
 #include <QUrl>
 #include <QSystemTrayIcon>
+#include <QTimeZone>
 
 using namespace KAlarmCal;
 
@@ -1271,7 +1273,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
     AlarmText          alarmText;
     KPIM::MailList     mailList;
     QList<QUrl>        files;
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::timeZone(true)));
+    MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::qTimeZone(true)));
 #ifndef NDEBUG
     QString fmts = data->formats().join(QStringLiteral(", "));
     qCDebug(KALARM_LOG) << fmts;
@@ -1339,9 +1341,9 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
             return;
         Todo::Ptr todo = todos[0];
         alarmText.setTodo(todo);
-        KDateTime start = todo->dtStart(true);
+        KDateTime start = q2k(todo->dtStart(true), todo->allDay());
         if (!start.isValid()  &&  todo->hasDueDate())
-            start = todo->dtDue(true);
+            start = q2k(todo->dtDue(true), todo->allDay());
         KAEvent::Flags flags = KAEvent::DEFAULT_FONT;
         if (start.isDateOnly())
             flags |= KAEvent::ANY_TIME;
